@@ -1,10 +1,7 @@
 # ABSTRACT: Response object for Dancer2
 
 package Dancer2::Core::Response;
-{
-  $Dancer2::Core::Response::VERSION = '0.12';
-}
-
+$Dancer2::Core::Response::VERSION = '0.13';
 use Moo;
 
 use Encode;
@@ -103,6 +100,7 @@ before content => sub {
     my $self = shift;
     if (ref($_[0]) and $self->has_serializer) {
         $_[0] = $self->serialize($_[0]);
+        $self->is_encoded(1); # All serializers return byte strings
     }
 };
 
@@ -212,7 +210,7 @@ Dancer2::Core::Response - Response object for Dancer2
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 ATTRIBUTES
 
@@ -294,7 +292,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Alexis Sukrieh.
+This software is copyright (c) 2014 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
